==> quanyi-center-api-1.1.44-merge-20240819.071708-38-sources.jar: cn/com/duiba/quanyi/center/api/param/pay/PayCreateOrderParam.java <==
package cn.com.duiba.quanyi.center.api.param.pay;

import cn.com.duiba.quanyi.center.api.enums.activity.PayChannelEnum;
import cn.com.duiba.quanyi.center.api.param.pay.ext.AlipayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.CcbPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.MinshengPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.InsuranceFundCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.HzBankCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.WxLiteCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.WxMpCreateOrderParam;
import lombok.Data;

import java.io.Serializable;

/**
 * 活动支付创建订单参数
 *
 * @author lizhi
 * @date 2023/8/7 18:20
 */
@Data
public class PayCreateOrderParam implements Serializable {

    private static final long serialVersionUID = 8894539309360592962L;

    /**
     * 订单业务主键
     */
    private Long payBizId;

    /**
     * 订单业务类型, 1-白名单活动，2-商品包
     *
     * @see cn.com.duiba.quanyi.center.api.enums.pay.PayBizTypeEnum
     */
    private Integer payBizType;

    /**
     * 支付类型
     *
     * @see cn.com.duiba.quanyi.center.api.enums.activity.PayChannelEnum
     */
    private Integer payChannel = PayChannelEnum.WX_PAY.getType();

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 支付金额，单位分
     */
    private Long payAmount;

    /**
     * 支付商品名称
     */
    private String goodsName;

    /**
     * 微信小程序支付参数
     */
    private WxLiteCreateOrderParam wxLite;

    /**
     * 浙江建行支付参数
     */
    private CcbPayCreateOrderParam ccb;

    /**
     * 支付宝支付参数
     */
    private AlipayCreateOrderParam alipay;

    /**
     * 保司资金账户
     */
    private InsuranceFundCreateOrderParam insuranceFund;

    /**
     * 民生银行支付参数
     */
    private MinshengPayCreateOrderParam minshengPay;

    /**
     * 杭州银行支付参数
     */
    private HzBankCreateOrderParam hzBank;

    /**
     * 微信公众号支付参数
     */
    private WxMpCreateOrderParam wxMp;

    /**
     * appId
     */
    private String appId;
    /**
     * 活动ID
     */
    private Long activityId;
    /**
     * 活动类型
     */
    private Integer activityType;

    /**
     * 优惠券json
     */
    private String couponJson;
}

==> quanyi-center-api-1.1.65-merge-20240928.101913-75-sources.jar: cn/com/duiba/quanyi/center/api/param/pay/PayCreateOrderParam.java <==
package cn.com.duiba.quanyi.center.api.param.pay;

import cn.com.duiba.quanyi.center.api.enums.activity.PayChannelEnum;
import cn.com.duiba.quanyi.center.api.param.pay.ext.AlipayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.CcbPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.HzBankCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.InsuranceFundCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.MinshengPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.PsbcPayCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.WxLiteCreateOrderParam;
import cn.com.duiba.quanyi.center.api.param.pay.ext.WxMpCreateOrderParam;
import lombok.Data;

import java.io.Serializable;

/**
 * 活动支付创建订单参数
 *
 * @author lizhi
 * @date 2023/8/7 18:20
 */
@Data
public class PayCreateOrderParam implements Serializable {

    private static final long serialVersionUID = 8894539309360592962L;

    /**
     * 订单业务主键
     */
    private Long payBizId;

    /**
     * 订单业务类型, 1-白名单活动，2-商品包
     *
     * @see cn.com.duiba.quanyi.center.api.enums.pay.PayBizTypeEnum
     */
    private Integer payBizType;

    /**
     * 支付类型
     *
     * @see cn.com.duiba.quanyi.center.api.enums.activity.PayChannelEnum
     */
    private Integer payChannel = PayChannelEnum.WX_PAY.getType();

    /**
     * 用户ID
     */
    private Long userId;

    /**
     * 支付金额，单位分
     */
    private Long payAmount;

    /**
     * 支付商品名称
     */
    private String goodsName;

    /**
     * 微信小程序支付参数
     */
    private WxLiteCreateOrderParam wxLite;

    /**
     * 浙江建行支付参数
     */
    private CcbPayCreateOrderParam ccb;

    /**
     * 支付宝支付参数
     */
    private AlipayCreateOrderParam alipay;

    /**
     * 保司资金账户
     */
    private InsuranceFundCreateOrderParam insuranceFund;

    /**
     * 民生银行支付参数
     */
    private MinshengPayCreateOrderParam minshengPay;

    /**
     * 杭州银行支付参数
     */
    private HzBankCreateOrderParam hzBank;

    /**
     * 微信公众号支付参数
     */
    private WxMpCreateOrderParam wxMp;

    /**
     * 邮储银行支付参数
     */
    private PsbcPayCreateOrderParam psbcPay;

    /**
     * appId
     */
    private String appId;
    /**
     * 活动ID
     */
    private Long activityId;
    /**
     * 活动类型
     */
    private Integer activityType;

    /**
     * 优惠券json
     */
    private String couponJson;
}
